Python library for unifying configuration handling
==================================================

A Python library for unifying configuration handling through config files, environment variables and
command line options.

Installation
------------

You can install `uniconfig` from PYPI by running `pip install uniconfig`.

If you want to update an existing install, run `pip install --update uniconfig`.

You can also clone this repository from github and run `pip install .` from the repository base directory.


License
-------
`uniconfig` is licensed under the Apache License, Version 2.0.
See [`LICENSE`](LICENSE) for details.
